@@ -1,5 +1,7 @@
 package v1
 
+const VulnerabilityStoreFileName = "vulnerability.db"
+
 // Vulnerability represents the minimum data fields necessary to perform package-to-vulnerability matching. This can represent a CVE, 3rd party advisory, or any source that relates back to a CVE.
 type Vulnerability struct {
 	ID                   string   // The identifier of the vulnerability or advisory
@@ -12,3 +14,18 @@ type Vulnerability struct {
 	ProxyVulnerabilities []string // IDs of other Vulnerabilities that are related to this one (this is how advisories relate to CVEs)
 	FixedInVersion       string   // The version which this particular vulnerability was fixed in
 }
+
+type VulnerabilityStore interface {
+	VulnerabilityStoreReader
+	VulnerabilityStoreWriter
+}
+
+type VulnerabilityStoreReader interface {
+	// GetVulnerability retrieves vulnerabilities associated with a namespace and a package name
+	GetVulnerability(namespace, name string) ([]Vulnerability, error)
+}
+
+type VulnerabilityStoreWriter interface {
+	// AddVulnerability inserts a new record of a vulnerability into the store
+	AddVulnerability(vulnerabilities ...Vulnerability) error
+}
