@@ -2,6 +2,8 @@ package v3
 
 const VulnerabilityStoreFileName = "vulnerability.db"
 
+type SerializedVulnerabilities = interface{}
+
 type VulnerabilityStore interface {
 	VulnerabilityStoreReader
 	VulnerabilityStoreWriter
@@ -10,6 +12,7 @@ type VulnerabilityStore interface {
 type VulnerabilityStoreReader interface {
 	// GetVulnerability retrieves vulnerabilities associated with a namespace and a package name
 	GetVulnerability(namespace, name string) ([]Vulnerability, error)
+	GetAllVulnerabilities() (*[]Vulnerability, error)
 }
 
 type VulnerabilityStoreWriter interface {
