@@ -1285,6 +1285,23 @@ func Test_DiffStore(t *testing.T) {
 				State: v4.UnknownFixState,
 			},
 		},
+		{
+			Namespace:         "nuget",
+			ID:                "GHSA-****-******",
+			PackageName:       "nuget:net",
+			VersionConstraint: "< 3.0 >= 2.17",
+			CPEs:              []string{"cpe:2.3:nuget:net:*:*:*:*:*:*"},
+			Fix: v4.Fix{
+				State: v4.UnknownFixState,
+			},
+		},
+		{
+			Namespace:         "hex",
+			ID:                "GHSA-^^^^-^^^^^^",
+			PackageName:       "hex:esbuild",
+			VersionConstraint: "< 3.0 >= 2.17",
+			CPEs:              []string{"cpe:2.3:hex:esbuild:*:*:*:*:*:*"},
+		},
 	}
 	baseMetadata := []v4.VulnerabilityMetadata{
 		{
@@ -1308,6 +1325,13 @@ func Test_DiffStore(t *testing.T) {
 			VersionConstraint: "< 3.0 >= 2.17",
 			CPEs:              []string{"cpe:2.3:golang:hashicorp:nomad:*:*:*:*:*"},
 		},
+		{
+			Namespace:         "github:language:go",
+			ID:                "GHSA-....-....",
+			PackageName:       "hashicorp:n",
+			VersionConstraint: "< 2.0 >= 1.17",
+			CPEs:              []string{"cpe:2.3:golang:hashicorp:n:*:*:*:*:*"},
+		},
 		{
 			Namespace:         "npm",
 			ID:                "CVE-123-7654",
@@ -1318,27 +1342,47 @@ func Test_DiffStore(t *testing.T) {
 				State: v4.WontFixState,
 			},
 		},
+		{
+			Namespace:         "nuget",
+			ID:                "GHSA-****-******",
+			PackageName:       "nuget:net",
+			VersionConstraint: "< 3.0 >= 2.17",
+			CPEs:              []string{"cpe:2.3:nuget:net:*:*:*:*:*:*"},
+			Fix: v4.Fix{
+				State: v4.UnknownFixState,
+			},
+		},
 	}
 	expectedDiffs := []v4.Diff{
 		{
-			Reason:    v4.DiffAdded,
-			ID:        "GHSA-....-....",
-			Namespace: "github:language:go",
+			Reason:    v4.DiffChanged,
+			ID:        "CVE-123-4567",
+			Namespace: "github:language:python",
+			Packages:  []string{"pypi:requests"},
 		},
 		{
 			Reason:    v4.DiffChanged,
 			ID:        "CVE-123-7654",
 			Namespace: "npm",
-		},
-		{
-			Reason:    v4.DiffRemoved,
-			ID:        "CVE-123-4567",
-			Namespace: "github:language:python",
+			Packages:  []string{"npm:axios"},
 		},
 		{
 			Reason:    v4.DiffRemoved,
 			ID:        "GHSA-****-******",
 			Namespace: "nuget",
+			Packages:  []string{"nuget:net"},
+		},
+		{
+			Reason:    v4.DiffAdded,
+			ID:        "GHSA-....-....",
+			Namespace: "github:language:go",
+			Packages:  []string{"hashicorp:n", "hashicorp:nomad"},
+		},
+		{
+			Reason:    v4.DiffRemoved,
+			ID:        "GHSA-^^^^-^^^^^^",
+			Namespace: "hex",
+			Packages:  []string{"hex:esbuild"},
 		},
 	}
 
@@ -1356,6 +1400,13 @@ func Test_DiffStore(t *testing.T) {
 	result, err := s1.DiffStore(s2)
 
 	//THEN
+	sort.SliceStable(*result, func(i, j int) bool {
+		return (*result)[i].ID < (*result)[j].ID
+	})
+	for i := range *result {
+		sort.Strings((*result)[i].Packages)
+	}
+
 	assert.NoError(t, err)
 	assert.Equal(t, expectedDiffs, *result)
 }
