@@ -10,8 +10,10 @@ type VulnerabilityStore interface {
 type VulnerabilityStoreReader interface {
 	// GetVulnerabilityNamespaces retrieves unique list of vulnerability namespaces
 	GetVulnerabilityNamespaces() ([]string, error)
-	// GetVulnerability retrieves vulnerabilities by namespace and package
-	GetVulnerability(namespace, packageName string) ([]Vulnerability, error)
+	// GetVulnerability retrieves vulnerabilities by namespace and id
+	GetVulnerability(namespace, id string) ([]Vulnerability, error)
+	// SearchForVulnerabilities retrieves vulnerabilities by namespace and package
+	SearchForVulnerabilities(namespace, packageName string) ([]Vulnerability, error)
 	GetAllVulnerabilities() (*[]Vulnerability, error)
 }
 
