@@ -3,8 +3,8 @@ package msrc
 import (
 	"github.com/anchore/grype/grype/distro"
 	"github.com/anchore/grype/grype/match"
-	"github.com/anchore/grype/grype/matcher/common"
 	"github.com/anchore/grype/grype/pkg"
+	"github.com/anchore/grype/grype/search"
 	"github.com/anchore/grype/grype/vulnerability"
 	syftPkg "github.com/anchore/syft/syft/pkg"
 )
@@ -24,17 +24,8 @@ func (m *Matcher) Type() match.MatcherType {
 }
 
 func (m *Matcher) Match(store vulnerability.Provider, d *distro.Distro, p pkg.Package) ([]match.Match, error) {
-	var matches []match.Match
-
 	// find KB matches for the MSFT version given in the package and version.
 	// The "distro" holds the information about the Windows version, and its
 	// patch (KB)
-	kbMatches, err := common.FindMatchesByPackageDistro(store, d, p, m.Type())
-	if err != nil {
-		return nil, err
-	}
-
-	matches = append(matches, kbMatches...)
-
-	return matches, nil
+	return search.ByCriteria(store, d, p, m.Type(), search.ByDistro)
 }
