@@ -5,7 +5,7 @@ import (
 
 	"github.com/scylladb/go-set/strset"
 
-	"github.com/anchore/syft/syft/pkg"
+	"github.com/anchore/syft/syft/cpe"
 )
 
 type UpstreamPackage struct {
@@ -30,20 +30,20 @@ func UpstreamPackages(p Package) (pkgs []Package) {
 
 		// for each cpe, replace pkg name with origin and add to set
 		cpeStrings := strset.New()
-		for _, cpe := range tmp.CPEs {
+		for _, c := range tmp.CPEs {
 			if u.Version != "" {
-				cpe.Version = u.Version
+				c.Version = u.Version
 			}
 
-			updatedCPEString := strings.ReplaceAll(cpe.BindToFmtString(), p.Name, u.Name)
+			updatedCPEString := strings.ReplaceAll(c.BindToFmtString(), p.Name, u.Name)
 
 			cpeStrings.Add(updatedCPEString)
 		}
 
 		// with each entry in set, convert string to CPE and update the new CPEs
-		var updatedCPEs []pkg.CPE
+		var updatedCPEs []cpe.CPE
 		for _, cpeString := range cpeStrings.List() {
-			updatedCPE, _ := pkg.NewCPE(cpeString)
+			updatedCPE, _ := cpe.New(cpeString)
 			updatedCPEs = append(updatedCPEs, updatedCPE)
 		}
 		tmp.CPEs = updatedCPEs
