@@ -10,6 +10,7 @@ func TestValidatedConfig(t *testing.T) {
 	cases := []struct {
 		name                    string
 		outputValue             string
+		includeSuppressed       bool
 		outputTemplateFileValue string
 		expectedConfig          Config
 		assertErrExpectation    func(assert.TestingT, error, ...interface{}) bool
@@ -17,6 +18,7 @@ func TestValidatedConfig(t *testing.T) {
 		{
 			"valid template config",
 			"template",
+			false,
 			"./template/test-fixtures/test.valid.template",
 			Config{
 				format:           "template",
@@ -27,6 +29,7 @@ func TestValidatedConfig(t *testing.T) {
 		{
 			"template file with non-template format",
 			"json",
+			false,
 			"./some/path/to/a/custom.template",
 			Config{},
 			assert.Error,
@@ -34,6 +37,7 @@ func TestValidatedConfig(t *testing.T) {
 		{
 			"unknown format",
 			"some-made-up-format",
+			false,
 			"",
 			Config{},
 			assert.Error,
@@ -42,9 +46,11 @@ func TestValidatedConfig(t *testing.T) {
 		{
 			"table format",
 			"table",
+			true,
 			"",
 			Config{
-				format: tableFormat,
+				format:         tableFormat,
+				showSuppressed: true,
 			},
 			assert.NoError,
 		},
@@ -52,7 +58,7 @@ func TestValidatedConfig(t *testing.T) {
 
 	for _, tc := range cases {
 		t.Run(tc.name, func(t *testing.T) {
-			actualConfig, actualErr := ValidatedConfig(tc.outputValue, tc.outputTemplateFileValue)
+			actualConfig, actualErr := ValidatedConfig(tc.outputValue, tc.outputTemplateFileValue, tc.includeSuppressed)
 
 			assert.Equal(t, tc.expectedConfig, actualConfig)
 			tc.assertErrExpectation(t, actualErr)
