@@ -12,7 +12,7 @@ const (
 )
 
 var matcherTypeStr = []string{
-	"UnknownSeverity",
+	"unknown severity",
 	"negligible",
 	"low",
 	"medium",
@@ -20,16 +20,20 @@ var matcherTypeStr = []string{
 	"critical",
 }
 
-var AllSeverities = []Severity{
-	NegligibleSeverity,
-	LowSeverity,
-	MediumSeverity,
-	HighSeverity,
-	CriticalSeverity,
+func AllSeverities() []Severity {
+	return []Severity{
+		NegligibleSeverity,
+		LowSeverity,
+		MediumSeverity,
+		HighSeverity,
+		CriticalSeverity,
+	}
 }
 
 type Severity int
 
+type Severities []Severity
+
 func (f Severity) String() string {
 	if int(f) >= len(matcherTypeStr) || f < 0 {
 		return matcherTypeStr[0]
@@ -54,3 +58,15 @@ func ParseSeverity(severity string) Severity {
 		return UnknownSeverity
 	}
 }
+
+func (s Severities) Len() int {
+	return len(s)
+}
+
+func (s Severities) Swap(i, j int) {
+	s[i], s[j] = s[j], s[i]
+}
+
+func (s Severities) Less(i, j int) bool {
+	return s[i] < s[j]
+}
