@@ -56,13 +56,25 @@ func (d *mockStore) stub() {
 	// METADATA /////////////////////////////////////////////////////////////////////////////////
 	d.metadata["CVE-2014-fake-1"] = map[string]*grypeDB.VulnerabilityMetadata{
 		"debian:distro:debian:8": {
-			Severity: "medium",
+			ID:        "CVE-2014-fake-1",
+			Namespace: "debian:distro:debian:8",
+			Severity:  "medium",
 		},
 	}
 
 	d.metadata["GHSA-2014-fake-3"] = map[string]*grypeDB.VulnerabilityMetadata{
 		"github:language:ruby": {
-			Severity: "medium",
+			ID:        "GHSA-2014-fake-3",
+			Namespace: "github:language:ruby",
+			Severity:  "medium",
+		},
+	}
+
+	d.metadata["CVE-2014-fake-3"] = map[string]*grypeDB.VulnerabilityMetadata{
+		"nvd:cpe": {
+			ID:        "CVE-2014-fake-3",
+			Namespace: "nvd:cpe",
+			Severity:  "critical",
 		},
 	}
 
