@@ -26,15 +26,14 @@ func (cfg externalSources) loadDefaultValues(v *viper.Viper) {
 	v.SetDefault("external-sources.maven.base-url", defaultMavenBaseURL)
 }
 
-func (cfg externalSources) ToJavaMatcherConfig(matchCfg matcherConfig) java.MatcherConfig {
+func (cfg externalSources) ToJavaMatcherConfig() java.ExternalSearchConfig {
 	// always respect if global config is disabled
 	smu := cfg.Maven.SearchUpstreamBySha1
 	if !cfg.Enable {
 		smu = cfg.Enable
 	}
-	return java.MatcherConfig{
+	return java.ExternalSearchConfig{
 		SearchMavenUpstream: smu,
 		MavenBaseURL:        cfg.Maven.BaseURL,
-		UseCPEs:             matchCfg.UseCPEs,
 	}
 }
